#!/bin/bash
#Automatically Created by buildpkg 1.7.0
#Maintainer: Pedro Pinto (pnboy~AT~pinguix.com)
#url: http://www.documentfoundation.org

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	for COMPLETED in $package.{txz,tgz,md5,dep}; do
		if [ "$KEEPDEPFILE" = "1" ] && [ $COMPLETED = $package.dep ]; then
			continue
		elif [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


check_for_menu_compliance() {
	if [ -d "$startdir/pkg/usr/share/applications" ]; then
		cd $startdir/pkg/usr/share/applications
		for desktop in *.desktop; do
			Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
				fi
				if [ -d "$startdir/pkg/usr/share/pixmaps" ]; then
					cd $startdir/pkg/usr/share/pixmaps
					for pixmaps in *; do
						[ -d $pixmaps ] && continue
						[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $startdir/pkg/usr/share/pixmaps)" ]]; then
								rm -rf $startdir/pkg/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$startdir/pkg/usr/share/icons" ]; then
					cd $startdir/pkg/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
							[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $icons $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}


gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			# I've never seen symlinks in info pages....
			if [ "$DOCS" == "man" ]; then
				(cd $startdir/pkg/usr/$DOCS
				for manpagedir in $(find . -type d -name "man*" 2> /dev/null) ; do
					( cd $manpagedir
					for eachpage in $( find . -type l -maxdepth 1 2> /dev/null) ; do
						ln -s $( readlink $eachpage ).gz $eachpage.gz
						rm $eachpage
					done )
				done)
			fi
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
}

set_post_permissions() {
	for DIRS in usr/share/icons usr/doc; do
		if [ -d "$startdir/pkg/$DIRS" ]; then
			if [ "$DIRS" == "usr/doc" ]; then
				find $startdir/pkg/$DIRS -type f -exec chmod 644 {} \;
				find $startdir/pkg/$DIRS -type d -exec chmod 755 {} \;
			fi
		fi
		[ -d $startdir/pkg/$DIRS ] && chown root:root -R $startdir/pkg/$DIRS
	done
	[ -d $startdir/pkg/usr/bin ] && find $startdir/pkg/usr/bin -user root -group bin -exec chown root:root {} \;
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
	[ -f $startdir/ZENBUILD ] && cp $startdir/ZENBUILD $startdir/pkg/usr/src/$pkgname-$pkgver/ZENBUILD
}

create_package() {
	ls -lR $startdir/pkg
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.$PKGEXTENSION
	cd $startdir
	md5sum $package.$PKGEXTENSION > $startdir/$package.md5
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}
#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
	        file=$(basename $SOURCES | awk -F= '{print $NF}')
		if [ ! -f "$file" ]; then
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
        	                wget $SOURCES -O $file
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $file $startdir/src
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/src/$pkgname-$pkgver/
		fi
		if [ "${SOURCES##*.}" == "desktop" ]; then
			[[ "$(grep -e "^Categories=[a-zA-Z]*;" $(basename $SOURCES))" ]] && install -D $startdir/$(basename $SOURCES) /home/pnboy/zenwalk/libreoffice/pkg/usr/share/applications/$(basename $SOURCES)
		fi
	done
}

extract_source() {
	cd $startdir/src
	if [[ "$(ls $startdir/src)" ]]; then	
		for FILES in ${source[@]}; do
	        	FILES="$(basename $FILES | awk -F= '{print $NF}')"
			file_type=$(file -biz "$FILES")
			unset cmd
			case "$file_type" in
				*application/x-tar*)
					cmd="tar -xf" ;;
				*application/zip*)
					cmd="unzip" ;;
				*application/x-zip*)
					cmd="unzip" ;;
				*application/x-gzip*)
					cmd="gunzip -d -f" ;;
				*application/x-bzip*)
					cmd="bunzip2 -f" ;;
			esac
			if [ "$cmd" != "" ]; then
				echo "$cmd $FILES"
	        	        $cmd $FILES
			fi
		done
	elif [ ! "$source" ]; then
		echo -n "" # lame fix
	else
		echo "no files in the src directory $startdir/src"
		exit 2
	fi
}

build() {
	cd $startdir/src/LibO_${pkgver%.*}*_Linux_x86_install-rpm_en-US/RPMS
	for file in *.rpm; do
		if ! `echo ${_toExtra[@]} | grep "${file}" 1>/dev/null 2>&1`
		then
			echo $file
			/usr/bin/rpm2targz $file || return 1
			tar xf $(basename "$file" .rpm).tar.gz -C $startdir/pkg || return 1
		fi
	done
	cd desktop-integration
	file=libreoffice${pkgver%.*}-freedesktop-menus-${pkgver%.*}-$_minorver.noarch.rpm
        echo $(basename "$file")
        /usr/bin/rpm2targz $file || return 1
        tar xvf $(basename "$file" .rpm).tar.gz -C $startdir/pkg || return 1
	cd $startdir/src/
	file=libreoffice-icon-theme-tango-3.3.0.3-2.1.noarch.rpm
        echo $(basename "$file")
        /usr/bin/rpm2targz $file || return 1
        tar xvf $(basename "$file" .rpm).tar.gz -C $startdir/pkg || return 1

	STRIMVER=${pkgver%.*}
	mkdir -p $startdir/pkg/usr/lib/libreoffice${pkgver%.*}
	cd $startdir/pkg/opt
	mv */* $startdir/pkg/usr/lib/libreoffice${pkgver%.*} || return 1
	rm -rf $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/program/python-core* || return 1
	cd $startdir/pkg/usr/lib/libreoffice${pkgver%.*}
	rm basis-link
	ln -s basis${pkgver%.*} basis-link
	mkdir -p $startdir/pkg/usr/share/applications/
	cd $startdir/pkg/usr/share/applications/
	for APPS in base calc draw impress math writer startcenter javafilter printeradmin ; do
		rm libreoffice-$APPS.desktop || return 1
        	ln -sf ../../lib/libreoffice${pkgver%.*}/share/xdg/$APPS.desktop libreoffice-${pkgver%.*}-$APPS.desktop || return 1
		sed -i -e "s|Icon=libreoffice-$APPS|Icon=openofficeorg-$APPS|g" libreoffice-${pkgver%.*}-$APPS.desktop || return 1
	done
	STRIMVER=${STRIMVER%.*}
	cd $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/share/xdg/
	mkdir -p $startdir/pkg/usr/bin/
	cd $startdir/pkg/usr/bin/
	ln -sf ../lib/libreoffice${pkgver%.*}/program/soffice soffice
	ln -sf ../lib/libreoffice${pkgver%.*}/program/unopkg unopkg
	mkdir -p $PKG/usr/share/icons/hicolor/48x48/mimetypes/
	install -d -m755 $startdir/pkg/usr/share/icons/hicolor/48x48/apps/
	install -v -m644 $startdir/pkg/usr/share/icons/hicolor/48x48/mimetypes/libreoffice-oasis-{text,presentation,database,drawing,spreadsheet,formula}.png $startdir/pkg/usr/share/icons/hicolor/48x48/apps/ || return 1

	sed -i "s|opt/libreoffice|usr/lib/libreoffice${pkgver%.*}|g" $startdir/pkg/usr/bin/libreoffice || return 1
	sed -i "s|opt/libreoffice3|usr/lib/libreoffice${pkgver%.*}|g" $startdir/pkg/usr/bin/libreoffice-printeradmin || return 1

	# Make symlinks to the binaries
	for APPS in base calc draw math writer padmin impress ; do
	cat << EoF > $startdir/pkg/usr/bin/oo$APPS
#!/bin/bash
exec /usr/lib/libreoffice${pkgver%.*}/program/s$APPS "\$@"
EoF
	chmod +x $startdir/pkg/usr/bin/oo$APPS
	done
#	cp $startdir/src/about.png $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/program/about.png || return 1
	cp $startdir/src/intro.png $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/program/intro.png || return 1
	rm -rvf $startdir/pkg/usr/share/applications/libreoffice3*.desktop
	rm -rfv $startdir/pkg/opt
	#sed -i -e "s|<value>auto</value>|<value>tango</value>|g" $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/share/registry/schema/org/libreoffice/Office/Common.xcs
	package2=$pkgname-extra-$pkgver-$arch-$zenver.$pkgrel
        mkdir -p $startdir/pkg2/install/
        cat << EOF > $startdir/pkg2/install/slack-desc
$pkgname-extra: $pkgname-extra (Extra open-office files)
$pkgname-extra: 
$pkgname-extra: Extra files for open-office(Math and Base).
EOF
	cd $startdir/src/LibO_${pkgver%.*}*_Linux_x86_install-rpm_en-US/RPMS
	for file in *.rpm; do
		if `echo ${_toExtra[@]} | grep "${file}" 1>/dev/null 2>&1`
		then
			echo $file
			/usr/bin/rpm2targz $file
			tar xf $(basename "$file" .rpm).tar.gz -C $startdir/pkg2
		fi
	done
        cd $startdir/pkg2/opt
        mkdir -p $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}
        cp -r */* $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}
	mkdir -p $startdir/pkg2/usr/share/applications/
	mkdir -p $startdir/pkg2/usr/bin/
	cd $startdir/pkg/usr/bin/
	mv oo{base,math} $startdir/pkg2/usr/bin/ || return 1
	mkdir -p $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/share/xdg/
	mv $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/share/xdg/{base,math}.desktop $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/share/xdg/ || return 1
	mv $startdir/pkg/usr/share/applications/libreoffice-${pkgver%.*}-{base,math}.desktop $startdir/pkg2/usr/share/applications/ || return 1
	cd $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/share/xdg/
	sed -i -e "s|libreoffice$STRIMVER -base %U|oobase|g" base.desktop || return 1
	sed -i -e "s|libreoffice$STRIMVER -math %U|oomath|g" math.desktop || return 1
	mkdir -p $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/share/config/
	mv $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/share/config/images*.zip $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/share/config/ || return 1
	mkdir -p $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/share/gallery/sounds
	mv $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/share/gallery/sounds $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/share/gallery/sounds || return 1
	mkdir -p $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/program/
	mv $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/program/classes $startdir/pkg2/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/program/classes/ || return 1
	rm -rvf $startdir/pkg2/opt
	cd $startdir/pkg2
        /sbin/makepkg -l y -c n $startdir/$package2.txz || return 1
        cd $startdir
        md5sum $package2.txz > $startdir/$package2.md5
	#create dep file
	echo "${extradepends[@]} libreoffice" | sed 's/ /\n/g' | sort -u | tr '\n' ','>$startdir/$package2.dep
	rm -rvf $startdir/pkg2
	unset package2
	cd $startdir/pkg/usr/bin/

	#fix symlinks problems
	cd $startdir/pkg/usr/lib
	ln -s libcrypto.so libcrypto.so.4
	ln -s libkdeui.so libkdeui.so.4
	ln -s libkdecore.so libkdecore.so.4
	ln -s libkabc.so libkabc.so.1
	ln -s libkio.so libkio.so.4

	mv $startdir/pkg/usr/share/libreoffice/basis${pkgver%.*}/share/config/images_tango.zip $startdir/pkg/usr/lib/libreoffice${pkgver%.*}/basis${pkgver%.*}/share/config/ 
	rm -rf $startdir/pkg/usr/share/libreoffice
} 

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
libreoffice: libreoffice (LibreOffice - Productivity Suite)
libreoffice: 
libreoffice: LibreOffice is a productivity suite that is compatible with other
libreoffice: major office suites, and available on a variety of platforms. It is
libreoffice: free software and therefore free to download, use and distribute.
libreoffice: 
libreoffice: 
libreoffice: 
libreoffice: 
libreoffice: 
libreoffice: 
EODESC
}

setup_doinst() {
cat <<"EODOINST" >>$startdir/pkg/install/doinst.sh
doinst() {
# update the mime desktop database
if [ -x usr/bin/update-desktop-database ]; then
        usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x usr/bin/update-mime-database ]; then
        usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
}
doinst
EODOINST
}
detect_dependencies() {
	echo "Detecting dependencies..."
	depends=""
	
	depstring=$depends,atk,avahi,cxxlibs,dbus,dbus-glib,e2fsprogs,expat,fontconfig,freetype,gcc,gconf,glib2,glitz,gnome-vfs,gst-plugins-base,gstreamer,gtk+2,icu,libICE,libSM,libX11,libXau,libXaw,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXft,libXi,libXinerama,libXmu,libXpm,libXrandr,libXrender,libXt,libXtst,libXxf86vm,libdrm,libpng,libxcb,libxml2,mesa,net-tools,openssl,orbit2,pango,perl,pixman,python,qt-base,xcb-util,zlib
	unset FIRST
	for deps in $(echo "${depstring}" | sed 's/,/\n/g' | sort -u); do
		if [[ ! "$FIRST" ]]; then
			finaldeps=$deps,
			FIRST='1'
			continue
		fi
		finaldeps=${finaldeps}${deps},
	done
	echo "$finaldeps" | sed -e 's/^,//' -e 's/,$//' > $startdir/$package.dep
}
create_source_file(){
	[ -f $package.src ] && rm $package.src
	if [ ! -z $sourcetemplate ]; then
		echo $sourcetemplate/ZENBUILD >> $package.src
		echo $sourcetemplate/build-$pkgname.sh >> $package.src
	else
		echo ZENBUILD >> $package.src
		echo build-$pkgname.sh >> $package.src
	fi
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			if [ ! -z $sourcetemplate ]; then
				echo $sourcetemplate/$(basename $SOURCES) >> $package.src
			else
				echo $(basename $SOURCES) >> $package.src
			fi
		else
			echo $SOURCES >> $package.src
		fi
	done
}
post_checks(){
	# Ideas taken from src2pkg :)
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		for DIRS in usr/doc/$pkgname-$pkgver usr/doc; do
			cd $startdir/pkg/$DIRS
			if [[ $(find . -type f) = "" ]] ; then
				cd ..
				rmdir $DIRS
			fi
		done
	fi
	# if the docs weren't deleted ...
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		cd $startdir/pkg/usr/doc/$pkgname-$pkgver
		#remove zero lenght files
		if [[ $(find . -type f -size 0) ]]; then
			echo "Removing some zero lenght files"
			find . -type f -size 0 -exec rm -f {} \;
		fi
	fi
	# check if we need to add code to handle info pages
	if [[ -d $startdir/pkg/usr/info ]] && [[ ! $(grep install-info $startdir/pkg/install/doinst.sh &> /dev/null) ]] ; then
		echo "Found info files - Adding install-info command to doinst.sh"
		INFO_LIST=$(ls -1 $startdir/pkg/usr/info)
		echo "" >> $startdir/pkg/install/doinst.sh
		echo "if [ -x usr/bin/install-info ] ; then" >> $startdir/pkg/install/doinst.sh
		for page in $(echo $INFO_LIST) ; do
			echo " usr/bin/install-info --info-dir=usr/info usr/info/$page 2>/dev/null" >> $startdir/pkg/install/doinst.sh
		done
		echo "fi" >> $startdir/pkg/install/doinst.sh
	fi
	[[ -e $startdir/pkg/usr/info/dir ]] && rm -f $startdir/pkg/usr/info/dir

	if [ -d $startdir/pkg/etc ]; then
		cd $startdir/pkg/
		for conf in $(find ./etc -type f) ; do
			conf=${conf: 2}
			dotnew=( "${dotnew[@]}" "$conf" )
		done
	fi
	if [[ "$dotnew" ]]; then
        for files in ${dotnew[@]} ; do
                fullfile="${startdir}/pkg/${files}"
                if [ -e "$fullfile" ]; then
                        mv $fullfile ${fullfile}.new
                else
                        echo "$fullfile was not found"
                        exit 2
                fi
        done
        cat<<"EODOTNEW" >>$startdir/pkg/install/doinst.sh
#Added by buildpkg 1.7.0
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
EODOTNEW
for i in ${dotnew[@]}; do
echo "dotnew $i" >> $startdir/pkg/install/doinst.sh
done
fi
}

PKGEXTENSION=txz

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=libreoffice
pkgver=3.3.1
pkgrel=1
zenver=70
arch=i586
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel
_minorver=8
_toExtra=(libobasis${pkgver%.*}-base-$pkgver-$_minorver.i586.rpm libobasis${pkgver%.*}-en-US-math-$pkgver-$_minorver.i586.rpm liboffice${pkgver%.*}-math-$pkgver-$_minorver.i586.rpm libobasis${pkgver%.*}-en-US-base-$pkgver-$_minorver.i586.rpm liboffice${pkgver%.*}-base-$pkgver-$_minorver.i586.rpm libobasis${pkgver%.*}-math-$pkgver-$_minorver.i586.rpm libobasis${pkgver%.*}-ooofonts-$pkgver-$_minorver.i586.rpm)
source=("http://download.documentfoundation.org/libreoffice/stable/3.3.1/rpm/x86/LibO_3.3.1_Linux_x86_install-rpm_en-US.tar.gz" "http://pnboy.pinguix.com/my_packages/zenwalk/libreoffice/3.3.1/intro.png" "http://pnboy.pinguix.com/my_packages/zenwalk/libreoffice/3.3.1/about.png" "http://download.opensuse.org/factory/repo/oss/suse/noarch/libreoffice-icon-theme-tango-3.3.0.3-2.1.noarch.rpm")
sourcetemplate=http://pnboy.pinguix.com/my_packages/zenwalk/libreoffice/3.3.1
docs=()
export CFLAGS="-O2 -march=i586 -mtune=i686"
export CXXFLAGS="-O2 -march=i586 -mtune=i686"

#Execution

check_for_root
clean_old_builds
prepare_directory
extract_source
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
post_checks
setup_doinst
check_for_menu_compliance
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
create_source_file
detect_dependencies
echo "Package has been built."
echo "Cleaning pkg and src directories"
clean_dirs
